import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:kmobile/src/preferences/color_dialog.dart';
import 'package:kmobile/src/preferences/language_dialog.dart';
import 'package:flutter_gen/gen_l10n/app_localizations.dart';
import 'package:kmobile/src/preferences/preferences_cubit.dart';
import 'package:kmobile/src/preferences/preferences_state.dart';

class Preference extends StatelessWidget {
  const Preference({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<PreferencesCubit, PreferencesState>(
      builder: (context, state) {
        return Scaffold(
          backgroundColor: Theme.of(context).colorScheme.background,
          appBar: AppBar(
            title: Text(AppLocalizations.of(context)!.preferences),
          ),
          body: ListView(
            children: [
              ListTile(
                title: Text(AppLocalizations.of(context)!.dark_theme),
                trailing: Switch(
                  value: state.themeMode == ThemeMode.dark,
                  onChanged: (value) {
                    context.read<PreferencesCubit>().setThemeMode(
                      value ? ThemeMode.dark : ThemeMode.light,
                    );
                  },
                ),
              ),
              const Divider(height: 0),
              ListTile(
                title: Text(AppLocalizations.of(context)!.color_theme),
                onTap: () => _changeCurrentTheme(context),
              ),
              const Divider(height: 0),
              ListTile(
                title: Text(AppLocalizations.of(context)!.language),
                onTap: () => _changeCurrentLocale(context),
              ),
            ],
          ),
        );
      },
    );
  }

  Future<void> _changeCurrentTheme(BuildContext context) async {
    final selectedColorScheme = await showDialog<Map<ThemeMode, ColorScheme>>(
      context: context,
      builder: (context) => const ColorDialog(),
    );

    if (context.mounted && selectedColorScheme != null) {
      context.read<PreferencesCubit>().setColorScheme(selectedColorScheme);
    }
  }

  Future<void> _changeCurrentLocale(BuildContext context) async {
    final selectedLocale = await showDialog<Locale>(
      context: context,
      builder: (context) => const LanguageDialog(),
    );

    if (context.mounted && selectedLocale != null) {
      context.read<PreferencesCubit>().setLocale(selectedLocale);
    }
  }
}
